@@ -1512,7 +1512,7 @@ int t2s (			/* Convert a time to a printable string */
 	dd = argp / 86400.0;		/* Days */
 	hh = (argp - dd * 86400.0) / 3600.0;	/* Hours */
 	mm = (argp - dd * 86400.0 - hh * 3600.0) / 60.0;	/* Minutes */
-	ss = argp - dd * 86400.0 - hh * 3600.0 - mm * 60.0;	/* Seconds */
+	ss = argp - dd * 86400.0 - hh * 3600.0 - mm * 60.0 + 0.5;	/* Seconds */
 	(void) sprintf (ps, "%03d-%02d:%02d:%02d", 1 + dd, hh, mm, ss);
 	return (0);			/* Normal end */
 	}				/* End of t2s() */
