@@ -25,7 +25,7 @@ set -- `ls -s ff-2843.ps` 0 no-such-file
 $verb && echo $@
 
 # did we make a plot?
-[ $1 -gt 78 ]
+[ $1 -ge 74 ]
 
 #
 # eof
