@@ -424,7 +424,7 @@ struct type_221 **t221)
         if (i == start_plot+nplots-1) cpgmtxt ("T", 0.5, 0.5, 0.5, "All");
         else 
             {
-            sprintf (buf, "\"%c\"", pass->pass_data[i].freq_code);
+            sprintf (buf, "%c", pass->pass_data[i].freq_code);
             cpgmtxt ("T", 0.5, 0.5, 0.5, buf);
             }
                                         /* Amplitudes in blue */
@@ -507,52 +507,14 @@ struct type_221 **t221)
             cpgmove (xr[j], 0.0);
             cpgdraw (xr[j], -plot.seg_frac_lsb[i][j]);
             }
-/*         for (j=0; j<np; j++) printf ("%d, %f %f %f %f\n", j, */
-/*                 plot.seg_referr_lcp[i][j], */
-/*                 plot.seg_referr_rcp[i][j], */
-/*                 plot.seg_remerr_lcp[i][j], */
-/*                 plot.seg_remerr_rcp[i][j]); */
-/*            fflush (stdout); */
                                         /* Draw box last - zero line is impt. */
         cpgsci (1);
         cpgbox ("AB", 0.0, 0.0, "BC", 0.0, 0.0);
-                                        /* Tape error statistics */
-        cpgsci (1);
-        cpgslw (1);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.39, 0.41);
-        cpgswin (0.0, (float)pass->num_ap, -6.0, -1.0);
-        cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
-                                        /* Ref station blue */
-        cpgsci (4);
-        for (j=0; j<np; j++)
-            {
-            if (plot.seg_referr[i][j] == 0.0) yr[j] = 0.0;
-            else yr[j] = log10 (plot.seg_referr[i][j]);
-            if (j > 0)
-                {
-                if ((yr[j] < 0.0) && (yr[j-1] < 0.0)) cpgdraw (xr[j], yr[j]);
-                else cpgmove (xr[j], yr[j]);
-                }
-            else cpgmove (xr[j], yr[j]);
-            } 
-                                        /* Rem station red */
-        cpgsci (2);
-        for (j=0; j<np; j++)
-            {
-            if (plot.seg_remerr[i][j] == 0.0) yr[j] = 0.0;
-            else yr[j] = log10 (plot.seg_remerr[i][j]);
-            if (j > 0)
-                {
-                if ((yr[j] < 0.0) && (yr[j-1] < 0.0)) cpgdraw (xr[j], yr[j]);
-                else cpgmove (xr[j], yr[j]);
-                }
-            else cpgmove (xr[j], yr[j]);
-            } 
                                         /* State count plots */
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.375, 0.39);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.395, 0.41);
         cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
         cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
                                         /* Ref station green */
@@ -599,7 +561,7 @@ struct type_221 **t221)
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.36, 0.375);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.38, 0.395);
         cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
         cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
                                         /* Ref station green */
@@ -646,7 +608,7 @@ struct type_221 **t221)
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.34, 0.36);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.36, 0.38);
         cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
         cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
                                         /* Ref station blue */
@@ -693,7 +655,7 @@ struct type_221 **t221)
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.32, 0.34);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.34, 0.36);
         cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
         cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
                                         /* Ref station blue */
@@ -740,7 +702,7 @@ struct type_221 **t221)
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.27, 0.32);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.29, 0.34);
                                         /* Draw tick marks on bottom edge, in */
                                         /* real seconds/minutes */
         xmin = plotstart;
@@ -994,7 +956,7 @@ struct type_221 **t221)
             (int)tickinc);
     psleft (0.05, 0.58, buf);   
                                         /* Switch to 110 font for the rest */
-    if (nplots > 15) pscat ("/Helvetica findfont 95 scalefont setfont\n");
+    if (nplots > 17) pscat ("/Helvetica findfont 95 scalefont setfont\n");
     else pscat ("/Helvetica findfont 110 scalefont setfont\n");
                                         /* See comment below for 1.03 factor */
     if (nplots > 1)
@@ -1005,52 +967,49 @@ struct type_221 **t221)
     psright (0.050,  0.429, "U");
     psleft  (0.000,  0.422, "Validity");
     psright (0.049,  0.413, "L");
-    psleft  (0.000,  0.395, "Parity");
-    psright (0.050,  0.379, "U");
-    psleft  (0.000,  0.372, "Bias");
-    psright (0.049,  0.365, "L");
-    psright (0.050,  0.345, "U");
-    psleft  (0.000,  0.335, "Level");
-    psright (0.049,  0.328, "L");
+    psright (0.050,  0.399, "U");
+    psleft  (0.000,  0.392, "Bias");
+    psright (0.049,  0.385, "L");
+    psright (0.050,  0.365, "U");
+    psleft  (0.000,  0.355, "Level");
+    psright (0.049,  0.348, "L");
                                         /* Label for tape error plots */
     xpos = labelpos + 0.003;
-                                        /* Color coded stations + SUs for tperr */
-    sprintf (buf, "%c (SU %d)", param.baseline[0], param.su_number[0]);
-    setblue;
-    psleft (xpos, 0.40, buf);
-    sprintf (buf, "%c (SU %d)", param.baseline[1], param.su_number[1]);
-    setred;
-    psleft (xpos, 0.39, buf);
                                         /* Color coded stations for bias */
     sprintf (buf, "%c", param.baseline[0]);
     setgreen;
-    psleft (xpos, 0.37, buf);
+    psleft (xpos, 0.39, buf);
     sprintf (buf, "%c", param.baseline[1]);
     setmagenta;
     xpos += 0.015;
-    psleft (xpos, 0.37, buf);
+    psleft (xpos, 0.39, buf);
     xpos -= 0.015;
                                         /* Color coded stations for level */
     sprintf (buf, "%c", param.baseline[0]);
     setblue;
-    psleft (xpos, 0.335, buf);
+    psleft (xpos, 0.355, buf);
     sprintf (buf, "%c", param.baseline[1]);
     setred;
     xpos += 0.015;
-    psleft (xpos, 0.335, buf);
+    psleft (xpos, 0.355, buf);
                                         /* Color coded stations for phasecal */
     sprintf (buf, "%c", param.baseline[0]);
     setgreen;
-    psleft (xpos, 0.290, buf);
+    psleft (xpos, 0.310, buf);
     sprintf (buf, "%c", param.baseline[1]);
     setmagenta;
     xpos += 0.015;
-    psleft (xpos, 0.290, buf);
+    psleft (xpos, 0.310, buf);
     setblack;
                                         /* Relocate text if only one plot */
     if (nplots == 2) labelpos = 0.30;
                                         /* use smaller font for bottom of plot rjc 030430 */
-    pscat ("/Helvetica findfont 95 scalefont setfont\n");
+    if (nplots < 10)
+        pscat ("/Helvetica findfont 95 scalefont setfont\n");
+    else if (nplots < 18)
+        pscat ("/Helvetica findfont 85 scalefont setfont\n");
+    else
+        pscat ("/Helvetica findfont 55 scalefont setfont\n");
     xposref = 0.0;
     xposrem = 0.0;
                                         // print manual pc_phases to zero out phase, mbd
@@ -1069,7 +1028,7 @@ struct type_221 **t221)
                                         /* and psleft macros, to support A4 paper */
                                         /* since pgplot coord system is letter */
         xpos = 0.05 + (i-start_plot)*plotwidth * 1.0304;
-        ypos = 0.255;
+        ypos = 0.275;
         spacing = 0.0095;
         sprintf (buf, "%.2f", pass->pass_data[i].frequency);
         psleft (xpos, ypos, buf);
@@ -1096,18 +1055,27 @@ struct type_221 **t221)
             }
         ypos -= spacing;
 
-        sprintf (buf, "%d:%d", 
+        sprintf (buf, "%d",                   // reference pcal frequencies
             (param.pc_mode[0] == MULTITONE) ? // source of pcal freqs dep. on mode
-                500.0 * bandwidth :           // midband in KHz
-                (int)pass->pass_data[i].pc_freqs[0][pass->pci[0][i]]/1000,
-            (param.pc_mode[1] == MULTITONE) ?
-                500.0 * bandwidth :
-                (int)pass->pass_data[i].pc_freqs[1][pass->pci[1][i]]/1000);
+                (int) (500 * bandwidth) :     // midband in KHz
+                (int)pass->pass_data[i].pc_freqs[0][pass->pci[0][i]]/1000);
         psleft (xpos, ypos, buf);
         if (i == start_plot) 
             {
             psleft (labelpos, ypos, "PC freqs");
-            sprintf (buf, "%c:%c", param.baseline[0], param.baseline[1]);
+            sprintf (buf, "%c", param.baseline[0]);
+            psright (0.04, ypos, buf);
+            }
+        ypos -= spacing;
+
+        sprintf (buf, "%d",                   // remote pcal frequencies
+            (param.pc_mode[1] == MULTITONE) ? // source of pcal freqs dep. on mode
+                (int) (500 * bandwidth) :     // midband in KHz
+                (int)pass->pass_data[i].pc_freqs[1][pass->pci[1][i]]/1000);
+        psleft (xpos, ypos, buf);
+        if (i == start_plot) 
+            {
+            sprintf (buf, "%c", param.baseline[1]);
             psright (0.04, ypos, buf);
             }
         ypos -= spacing;
@@ -1133,6 +1101,12 @@ struct type_221 **t221)
         ypos -= spacing;
 
                                     // color code pcal amplitudes  rjc 2009.3.10
+        if (i == start_plot) 
+            {
+            psleft (labelpos, ypos, "PC amp");
+            sprintf (buf, "%c", param.baseline[0]);
+            psright (0.04, ypos, buf);
+            }
         pcaref = rint (1000.0 * (double)fringe.t207->ref_pcamp[i].lsb);
         pcarem = rint (1000.0 * (double)fringe.t207->rem_pcamp[i].lsb);
         
@@ -1142,8 +1116,9 @@ struct type_221 **t221)
             setorange;
         else
             setgreen;
-        sprintf (buf, "%d:", pcaref);
+        sprintf (buf, "%d", pcaref);
         psleft (xpos, ypos, buf);
+        ypos -= spacing;
 
         if (pcarem < 4 || pcarem >= 150)
             setred;
@@ -1153,12 +1128,11 @@ struct type_221 **t221)
             setgreen;
         sprintf (buf, "%d", pcarem);
 
-        psleft ((float)(xpos+0.025), ypos, buf);
+        psleft (xpos, ypos, buf);
         setblack;
         if (i == start_plot) 
             {
-            psleft (labelpos, ypos, "PC amp");
-            sprintf (buf, "%c:%c", param.baseline[0], param.baseline[1]);
+            sprintf (buf, "%c", param.baseline[1]);
             psright (0.04, ypos, buf);
             }
         ypos -= spacing;
@@ -1189,7 +1163,7 @@ struct type_221 **t221)
             ypos += spacing/2.0;
             }
         ypos -= spacing;
-                                        /* Color-coded tracks, reference station */
+                                        /* reference station */
         buf[0] = '\0';
                                         /* Empirical value for 110-scaled helvetica */
         digitwidth = 0.0066;            /* 95-scaled helvetica */
@@ -1201,7 +1175,7 @@ struct type_221 **t221)
         first = TRUE;
         for (j=0; j<16; j++)
             {
-            if ((pass->pass_data[i].trk_lcp[0][j] >= 0) && (pol[0] == 'L'))
+            if ((pass->pass_data[i].trk_lcp[0][j] > 0) && (pol[0] == 'L'))
                 {
                 sprintf (buf, "%d", pass->pass_data[i].trk_lcp[0][j]);
                 xposref = xpos + offset;
@@ -1211,7 +1185,7 @@ struct type_221 **t221)
                 offset += digitwidth * strlen (buf);
                 first = FALSE;
                 }
-            if ((pass->pass_data[i].trk_rcp[0][j] >= 0) && (pol[0] == 'R'))
+            if ((pass->pass_data[i].trk_rcp[0][j] > 0) && (pol[0] == 'R'))
                 {
                 sprintf (buf, "%d", pass->pass_data[i].trk_rcp[0][j]);
                 xposref = xpos + offset;
@@ -1253,7 +1227,7 @@ struct type_221 **t221)
         first = TRUE;
         for (j=0; j<16; j++)
             {
-            if ((pass->pass_data[i].trk_lcp[1][j] >= 0) && (pol[1] == 'L'))
+            if ((pass->pass_data[i].trk_lcp[1][j] > 0) && (pol[1] == 'L'))
                 {
                 sprintf (buf, "%d", pass->pass_data[i].trk_lcp[1][j]);
                 xposrem = xpos + offset;
@@ -1263,7 +1237,7 @@ struct type_221 **t221)
                 offset += digitwidth * strlen (buf);
                 first = FALSE;
                 }
-            if ((pass->pass_data[i].trk_rcp[1][j] >= 0) && (pol[1] == 'R'))
+            if ((pass->pass_data[i].trk_rcp[1][j] > 0) && (pol[1] == 'R'))
                 {
                 sprintf (buf, "%d", pass->pass_data[i].trk_rcp[1][j]);
                 xposrem = xpos + offset;
@@ -1300,7 +1274,7 @@ struct type_221 **t221)
     if (nplots > 2)
         {
         xpos = 1.0;
-        ypos = 0.255;
+        ypos = 0.275;
         psright (xpos, ypos, "All");
         ypos -= spacing;
         sprintf (buf, "%.1f", status.resid_phase);
@@ -1314,6 +1288,7 @@ struct type_221 **t221)
         }
 /*     ypos = 0.15; */
     ypos = 0.130;
+    pscat ("/Helvetica findfont 95 scalefont setfont\n");
     psleft (0.0, ypos, "Group delay (usec)"); ypos -= 0.01;
     psleft (0.0, ypos, "Sband delay (usec)"); ypos -= 0.01;
     psleft (0.0, ypos, "Phase delay (usec)"); ypos -= 0.01;
